embassy-stm32

Crates

git

Versions

stm32h757xi-cm7

Flavors

DsiPanel

Trait DsiPanel 

pub trait DsiPanel {
Show 17 associated constants and 2 methods const ACTIVE_WIDTH: u16; const ACTIVE_HEIGHT: u16; const HBP: u16; const HFP: u16; const VBP: u16; const VFP: u16; const HSYNC: u16; const VSYNC: u16; const HSYNC_POLARITY: PolarityActive; const VSYNC_POLARITY: PolarityActive; const DATA_ENABLE_POLARITY: PolarityActive; const PIXEL_CLOCK_POLARITY: PolarityEdge; const LP_MAX_PACKET_SIZE: u8; const VACT_MAX_PACKET_SIZE: u8; const NULL_PACKET_SIZE: u16; const LOOSELY_PACKED: bool; const HLINE_TOTAL: u16 = _; // Required method async fn init<DSI: Instance>( dsi: &mut DsiHost<'_, DSI>, color: DsiColor, ) -> Result<(), Error>; // Provided method fn ltdc_config() -> LtdcConfiguration { ... }
}
DSI Panel trait

This trait must be implemented by supported panels to provide timing information and perform a vendor specific init sequence.

Required Associated Constants

const ACTIVE_WIDTH: u16

Active panel width in pixels

const ACTIVE_HEIGHT: u16

Active panel height in pixels

const HBP: u16

Horizontal back porch

const HFP: u16

Horizontal front porch

const VBP: u16

Vertical back porch

const VFP: u16

Vertical front porch

const HSYNC: u16

Horizontal sync width

const VSYNC: u16

Vertical sync width

const HSYNC_POLARITY: PolarityActive

Horizontal sync polarity

const VSYNC_POLARITY: PolarityActive

Vertical sync polarity

const DATA_ENABLE_POLARITY: PolarityActive

Data enable polarity

const PIXEL_CLOCK_POLARITY: PolarityEdge

Pixel clock edge polarity

const LP_MAX_PACKET_SIZE: u8

Maximum low power packet size

const VACT_MAX_PACKET_SIZE: u8

Maximum low power VACT packet size

const NULL_PACKET_SIZE: u16

Size of a null packet in Sync Pulse or Event modes

const LOOSELY_PACKED: bool

Enable loose packed in RGB666 Video mode

Provided Associated Constants

const HLINE_TOTAL: u16 = _

Total horizontal line

Required Methods

async fn init<DSI: Instance>( dsi: &mut DsiHost<'_, DSI>, color: DsiColor, ) -> Result<(), Error>

Run panel specific DSI command initialization

Provided Methods

fn ltdc_config() -> LtdcConfiguration

Return an LtdcConfiguration for this panel

NOTE: The polarities are set for communication between LTDC and DSIHOST and are not the values specific to the panel, which are handled by DSI.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors